#!/usr/bin/env node
/**
 * Cty2JSON ver 0.11.5
 * Copyright (C) 2015-2019 Tom Konda
 * Released under the GPLv3 license
 * See https://www.gnu.org/licenses/gpl-3.0.en.html
 */
'use strict';

Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const promisify = require('util.promisify');
const fs = require("fs");
const Cty2JSON = require('../index');
const packageInfo = JSON.parse(fs.readFileSync(`${__dirname}/../package.json`).toString());
const fileAccessCheck = (inputFile) => {
    let isfileReadable;
    if (typeof fs.constants === 'undefined') {
        // for Node 4.x
        isfileReadable = fs.R_OK;
    }
    else {
        isfileReadable = fs.constants.R_OK;
    }
    return promisify(fs.access)(inputFile, isfileReadable);
};
const fileFormatCheck = (inputfile) => {
    const uint8arr = new Uint8Array(inputfile);
    try {
        const ctyData = Cty2JSON.outputJSONText(uint8arr.buffer);
        return Promise.resolve(ctyData);
    }
    catch (error) {
        return Promise.reject(error);
    }
};
const convertCty2JSON = async (inputCTYFile, options) => {
    try {
        await fileAccessCheck(inputCTYFile);
        const file = await promisify(fs.readFile)(inputCTYFile);
        const JSONText = await fileFormatCheck(file);
        const outputFile = options.output;
        if (outputFile) {
            await promisify(fs.writeFile)(outputFile, JSONText);
            process.stdout.write(`${outputFile} was created successfully.\n`);
        }
        else {
            process.stdout.write(JSONText);
        }
    }
    catch (error) {
        console.log(error);
        console.error('Cannot write a JSON file.');
        if (error instanceof RangeError) {
            process.stderr.write(`-1 : ${error.message}\n`);
            process.exit(-1);
        }
        else if (error instanceof Error) {
            process.stderr.write(`${error.errno} : ${error.message}\n`);
            process.exit(error.errno);
        }
    }
};
commander.version(packageInfo.version)
    .command('<inputFile>', 'Path to a Micropolis .cty file')
    .option('-o, --output <outputFile>', 'Output JSON file')
    .description('Output JSON File from a Micropolis cty file')
    .usage('[options] <inputFile>')
    .action(convertCty2JSON)
    .parse(process.argv);
